# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), 
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.17.0] - 2022-01-04

### Added

* Categorical eligibility for SNAP, including broad-based categorical eligibility via low-cost TANF programs that effectively extend SNAP's asset and income limits.

### Changed

* Refactored SNAP code.

## [0.16.0] - 2022-01-03

### Added

* CCDF subsidy top-level logic

## [0.15.0] - 2022-01-03

### Added

* Federal SNAP asset tests logic

## [0.14.0] - 2022-01-03

### Added

* SNAP eligibility based on federal net and gross income limits.
* Unit and integration tests for SNAP variables.

## [0.13.0] - 2021-12-31

### Added

* Formula for Medicaid person type, based on age and dependents.
* Variable for whether a person meets their Medicaid income eligibility requirement.

## [0.12.0] - 2021-12-30

### Added

* Elderly and Disabled (tax) Credit.

## [0.11.0] - 2021-12-30

### Added

* American Opportunity (tax) Credit.
* Lifetime Learning (tax) Credit.

## [0.10.0] - 2021-12-28

### Added

* Income-to-SMI (state median income) ratio.

## [0.9.0] - 2021-12-28

### Added

* Social Security taxation logic.

## [0.8.0] - 2021-12-28

### Added 

* Minimum benefit logic for SNAP.

## [0.7.0] - 2021-12-28

### Added

* Gains Tax (capital gains treatment) logic and parameters.

## [0.6.0] - 2021-12-28

### Added

* Alternative Minimum Tax (AMT) income and liability logic.
* Development tools for auto-generating unit tests for Tax-Calculator functions.

## [0.5.0] - 

### Added

* Medicaid income thresholds for California.

## [0.4.0] - 2021-12-26

### Added

* TANF eligibility, broken down into demographic and financial variables, with financial separated by current enrollment in program.
* Demographic TANF eligibility per IL rules.

## [0.3.1] - 2021-12-25

### Added

* Automated tests.

## [0.3.0] - 2021-12-25

### Added

* Lifeline benefit.

## 0.0.1 - 2021-06-28

### Added

* First prototype version with a standard deduction variable.
